==> apache-samza-0.14.1-src.tgz: apache-samza-0.14.1-src/samza-core/src/main/java/org/apache/samza/coordinator/CoordinationUtils.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.samza.coordinator;

import org.apache.samza.annotation.InterfaceStability;

/**
 *
 * Coordination service provides synchronization primitives.
 * The actual implementation (for example ZK based) is left to each implementation class.
 * This service provide three primitives:
 *   - LeaderElection
 *   - Latch
 *   - LockWithState (does not lock if state is set)
 */
@InterfaceStability.Evolving
public interface CoordinationUtils {

  // facilities for group coordination
  LeaderElector getLeaderElector(); // leaderElector is unique based on the groupId

  Latch getLatch(int size, String latchId);

  DistributedLockWithState getLockWithState(String lockId);

  /**
   * utilites cleanup
   */
  void close();
}

==> apache-samza-1.6.0-src.tgz: apache-samza-1.6.0-src/samza-core/src/main/java/org/apache/samza/coordinator/CoordinationUtils.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.samza.coordinator;

import org.apache.samza.annotation.InterfaceStability;

/**
 *
 * Coordination service provides synchronization primitives.
 * The actual implementation (for example ZK based) is left to each implementation class.
 * This service provides the following primitives:
 *   - LeaderElection
 *   - Latch
 *   - Lock
 *   - ClusterMembership (to check number of processors in quorum)
 */
@InterfaceStability.Evolving
public interface CoordinationUtils {

  // facilities for group coordination
  LeaderElector getLeaderElector(); // leaderElector is unique based on the groupId

  Latch getLatch(int size, String latchId);

  DistributedLock getLock(String lockId);

  ClusterMembership getClusterMembership();

  /**
   * utilites cleanup
   */
  void close();
}
